@@ -198,7 +198,7 @@ public:
     \return Index (signed).
     \warning The global index is generally not the index in the current chunk.
     */
-    long i()
+    long i() const
     {
         return m_istart + static_cast<long>(m_li);
     }
@@ -306,7 +306,7 @@ public:
     }
 
     /**
-    Reset the system: Overwrite the current chunk and global index.
+    Overwrite the current chunk and global index.
 
     \tparam T The type of the contain `y`. Should implement `begin()` and `end()``.
 
@@ -332,7 +332,7 @@ public:
     }
 
     /**
-    Reset the system: Overwrite the current chunk and global index.
+    Overwrite the current chunk and global index.
 
     \tparam T The type of the contain `y`. Should implement `begin()` and `end()``.
 
@@ -618,8 +618,11 @@ public:
     }
 
     /**
-    Shift chunk chunk of yield positions.
+    Shift chunk chunk of yield positions, by supplying the yield distances for a sequential chunk.
     The shift may be left or right, but there may not be any holes compared to the current chunk.
+    Note that the yield distances are converted to yield positions using the chunk currently held
+    in memory.
+    This is the reason why there may be not any holes between the old and new chunks.
 
     \tparam T The type of the contain `y`. Should implement `begin()` and `end()``.
 
@@ -647,7 +650,27 @@ public:
 
     /**
     Set the current position.
+
     \param x The current position.
+
+    \b Note
+
+    If the position is outside the current chunk of yield positions, the class will be locked.
+    To continue one has to first supply the appropriate chunk of yield positions.
+    For the latter, check the needed direction to move in the sequence of yield positions
+    using redraw() (which can also be used to verify that no new chunk is needed),
+    and then use shift_y(), shift_dy() to supply a neighbouring chunk
+    (or directly using lshift_y() or lshift_dy(), and rshift_y() or rshift_dy()),
+    or set_y() to supply an arbitrary chunk.
+
+    To be ahead of running out-of-bounds one can use boundcheck_left() and boundcheck_right()
+    to register that the 'particle' is close to the left or right edge of the current chunk of
+    yield positions.
+    If that is the case, use shift_y(), shift_dy() to supply a neighbouring chunk
+    (or directly using lshift_y() or lshift_dy(), and rshift_y() or rshift_dy())
+    in combination with a buffer to make sure that the current position stays in bounds.
+
+    You can also use redraw(double) to perform a trial step.
     */
     void set_x(double x)
     {
@@ -656,18 +679,42 @@ public:
     }
 
     /**
-    Check for redraw:
+    Based on the last specified positions,
+    check for redraw:
     -   0: No redraw needed.
     -   -1: To the left.
     -   +1: To the right.
 
-    \return Redraw direction
+    \return Redraw direction.
     */
     int redraw() const
     {
         return m_redraw;
     }
 
+    /**
+    Based on a trial positions,
+    check for redraw:
+    -   0: No redraw needed.
+    -   -1: To the left.
+    -   +1: To the right.
+
+    Note that internally the position is not updated.
+
+    \return Redraw direction.
+    */
+    int redraw(double xtrial) const
+    {
+        if (xtrial <= m_y.front()) {
+            return -1;
+        }
+        else if (xtrial > m_y.back()) {
+            return +1;
+        }
+
+        return 0;
+    }
+
     /**
     Yield position directly left of x().
     Same as y()[i() - istart()].
@@ -804,7 +851,12 @@ private:
     double m_left; ///< See yleft()
     double m_right; ///< See yright()
     std::vector<double> m_y; ///< Current chunk of yield positions
-    double m_ymin_data = 0.0; ///< The value of ymin() of the supplied data (excl. buffer)
+
+    /**
+    The value left-most value of the last supplied `y`.
+    Note that when a buffer is used typically `m_ymin_data != m_y(0)`.
+    */
+    double m_ymin_data = 0.0;
 
 }; // class Chunked
 
